@@ -7,4 +7,6 @@ summary.autoKrige = function(object, ...)
      print(object$exp_var)
      cat("\nvar_model:\n")
      print(object$var_model)
+	 cat("Sums of squares betw. var. model and sample var.")
+	 print(object$sserr)
 }
